@@ -1,7 +1,4 @@
 #!/usr/bin/perl
-
-eval 'exec /usr/bin/perl  -S $0 ${1+"$@"}'
-    if 0; # not running under some shell
 #!d:\perl\bin\perl.exe
 #
 # Filename: stubmaker.pl
